Get R version information on the R instance that webR provides
Source:R/rw_r_info.R, R/rw_version.R
version-functions.RdFunctions to retrieve version information about the rw CLI, webR, and R.
Value
rw_r_info() returns R.Version() in webR and rw_r_info(template)
returns a character string based on the format in webR.
rw_version() returns the version of the rw CLI tool as a
numeric_version object.
rw_webr_version() returns the version of webR as a
numeric_version object.
rw_r_version() returns the R version running in webR as a
numeric_version object.